==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/kinesis/kotlin/inputs/GetStreamPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.kinesis.kotlin.inputs

import com.pulumi.aws.kinesis.inputs.GetStreamPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * A collection of arguments for invoking getStream.
 * @property name Name of the Kinesis Stream.
 * @property tags Map of tags to assigned to the stream.
 */
public data class GetStreamPlainArgs(
    public val name: String,
    public val tags: Map<String, String>? = null,
) : ConvertibleToJava<com.pulumi.aws.kinesis.inputs.GetStreamPlainArgs> {
    override fun toJava(): com.pulumi.aws.kinesis.inputs.GetStreamPlainArgs =
        com.pulumi.aws.kinesis.inputs.GetStreamPlainArgs.builder()
            .name(name.let({ args0 -> args0 }))
            .tags(tags?.let({ args0 -> args0.map({ args0 -> args0.key.to(args0.value) }).toMap() })).build()
}

/**
 * Builder for [GetStreamPlainArgs].
 */
@PulumiTagMarker
public class GetStreamPlainArgsBuilder internal constructor() {
    private var name: String? = null

    private var tags: Map<String, String>? = null

    /**
     * @param value Name of the Kinesis Stream.
     */
    @JvmName("vkbfnbeshtofgkvq")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.name = mapped
    }

    /**
     * @param value Map of tags to assigned to the stream.
     */
    @JvmName("dhgkxkopfpiusybf")
    public suspend fun tags(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.tags = mapped
    }

    /**
     * @param values Map of tags to assigned to the stream.
     */
    @JvmName("wfrsrjdkbijhxplj")
    public fun tags(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.tags = mapped
    }

    internal fun build(): GetStreamPlainArgs = GetStreamPlainArgs(
        name = name ?: throw PulumiNullFieldException("name"),
        tags = tags,
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/kinesis/kotlin/inputs/GetStreamPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.kinesis.kotlin.inputs

import com.pulumi.aws.kinesis.inputs.GetStreamPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * A collection of arguments for invoking getStream.
 * @property name Name of the Kinesis Stream.
 * @property tags Map of tags to assigned to the stream.
 */
public data class GetStreamPlainArgs(
    public val name: String,
    public val tags: Map<String, String>? = null,
) : ConvertibleToJava<com.pulumi.aws.kinesis.inputs.GetStreamPlainArgs> {
    override fun toJava(): com.pulumi.aws.kinesis.inputs.GetStreamPlainArgs =
        com.pulumi.aws.kinesis.inputs.GetStreamPlainArgs.builder()
            .name(name.let({ args0 -> args0 }))
            .tags(tags?.let({ args0 -> args0.map({ args0 -> args0.key.to(args0.value) }).toMap() })).build()
}

/**
 * Builder for [GetStreamPlainArgs].
 */
@PulumiTagMarker
public class GetStreamPlainArgsBuilder internal constructor() {
    private var name: String? = null

    private var tags: Map<String, String>? = null

    /**
     * @param value Name of the Kinesis Stream.
     */
    @JvmName("tmggpkqhctwiiuhl")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.name = mapped
    }

    /**
     * @param value Map of tags to assigned to the stream.
     */
    @JvmName("ecdjfvssjxcpvyrg")
    public suspend fun tags(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.tags = mapped
    }

    /**
     * @param values Map of tags to assigned to the stream.
     */
    @JvmName("lajwixwrwrvljysm")
    public fun tags(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.tags = mapped
    }

    internal fun build(): GetStreamPlainArgs = GetStreamPlainArgs(
        name = name ?: throw PulumiNullFieldException("name"),
        tags = tags,
    )
}
